import os
import json
import boto3
import botocore

s3client  = boto3.client('s3', 'us-east-1', config=botocore.config.Config(s3={'addressing_style':'path'}))

def s3getlist(bucket,Prefix):
    res  = s3client.list_objects_v2(Bucket=bucket,  Prefix=Prefix)
    key=[]
    if 'Contents' in res:
        for _content in res['Contents']:
            if _content['Key'].find('metadata') > -1:
                d= 0
            else:
                key.append(_content['Key'])
    return key
    
def gen_surl(bucketname, keyname):
    url = s3client.generate_presigned_url(ClientMethod='get_object', Params={'Bucket': bucketname, 'Key': keyname})
    return url
    
def bucket_putpriv_v1(bucket, key,  acl):
    srep = s3client.put_object_acl(ACL=acl, Bucket=bucket, Key=key)
    return srep
    
def bucket_putpriv(bucket, key, body,type):
    srep = s3client.put_object(
        ACL='private', Body=body, Bucket=bucket, Key=key, ContentType=type,)
    print(srep)
    return srep
    
def bucket_get_obj(bucket, bkey):
    object = s3client.get_object(Bucket=bucket, Key=bkey)
    return(object['Body'].read().decode('utf-8'))
    
def lambda_handler(event, context):
    print(json.dumps(event))
    _rhtml = ''
    ctype='text/html'
    try:
        
        bucket  = os.environ['S3Bucket']
        prefix  = os.environ['prefix']
 
        s3key  = event['queryStringParameters']['s3key']
        action  = event['queryStringParameters']['action']
        if action == 'wwwsvr':
            wwwkey = f'{prefix}{s3key}'
            print(wwwkey)
            ctype='text/html'
            if wwwkey.find('.js') > -1:
                    ctype='text/javascript'
            if wwwkey.find('.css') > -1:
                    ctype='text/css'
            if wwwkey.find('.json') > -1:
                ctype='text/json'
        _prehtml = bucket_get_obj(bucket,wwwkey)
        _rhtml = _prehtml
    except  Exception as e:
        print(e)
        _rhtml = f'Error with {str(e)}'
    finally:
        response = {
                        "statusCode": 200,
                        "body": _rhtml,
                        "headers": {
                            'Content-Type': ctype,
                        }}
        return response
    
    